Data documentation compiled by Great Expectations

### Overview

#### Dataset info

Number of variables | 6
Number of observations expect_table_row_count_to_be_between | ?
Missing cells | ?

#### Variable types

int | 0
float | 0
string | 0
-- | 6

#### Expectation types

- expect_column_to_exist 6
- expect_column_mean_to_be_between 1
- expect_column_values_to_be_between 1
- expect_column_values_to_match_regex 1
- expect_column_values_to_be_in_set 1

### Age expect_column_to_exist

##### Type: -- expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Statistics

Mean expect_column_mean_to_be_between | 30.40

#### Expectation types

- expect_column_to_exist True
- expect_column_mean_to_be_between True
- expect_column_values_to_be_between True

### Name expect_column_to_exist

##### Type: -- expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Expectation types

- expect_column_to_exist True
- expect_column_values_to_match_regex True

### PClass expect_column_to_exist

##### Type: -- expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Example Values expect_column_values_to_be_in_set

*

#### Expectation types

- expect_column_to_exist True
- expect_column_values_to_be_in_set False

### Sex expect_column_to_exist

##### Type: -- expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Expectation types

- expect_column_to_exist True

### SexCode expect_column_to_exist

##### Type: -- expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Expectation types

- expect_column_to_exist True

### Survived expect_column_to_exist

##### Type: -- expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Expectation types

- expect_column_to_exist True

Documentation autogenerated using Great Expectations .

This is a beta feature! Expect changes in API, behavior, and design.

Documentation autogenerated using Great Expectations .

This is a beta feature! Expect changes in API, behavior, and design.